@@ -145,12 +145,19 @@ class PodiumAPI(object):
     def extract_api_error(cls, results: Any) -> str:
         if type(results) == ConnectionRefusedError:
             return "Connection Refused"
-        errors = results.get("errors", {}).get("base")
-        if errors and len(errors):
-            return errors[0]
-        message = errors.get("message")
-        return message if message else "Unknown error"
+        errors = results.get("errors", {})
         
+        error_msg = ""
+        for k,v in errors.items():
+            if len(error_msg):
+                error_msg += "; "
+            error_msg += f"{k}: "
+            if isinstance(v, list) and len(v):
+                error_msg += v[0]
+            else:
+                error_msg += str(v)
+                
+        return error_msg if error_msg else "Unknown error"
 
 class PodiumLapsAPI(object):
     """
