@@ -1,15 +1,21 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from podium_api.asyncreq import make_request_custom_success, get_json_header_token
-from podium_api.types.device import get_device_from_json
-from podium_api.types.redirect import get_redirect_from_json
-from podium_api.types.paged_response import get_paged_response_from_json
 import podium_api
+from podium_api.asyncreq import get_json_header_token, make_request_custom_success
+from podium_api.types.device import get_device_from_json
+from podium_api.types.paged_response import get_paged_response_from_json
+from podium_api.types.redirect import get_redirect_from_json
 
 
-def make_device_update(token, device_uri, name=None,
-                       success_callback=None, failure_callback=None,
-                       progress_callback=None, redirect_callback=None):
+def make_device_update(
+    token,
+    device_uri,
+    name=None,
+    success_callback=None,
+    failure_callback=None,
+    progress_callback=None,
+    redirect_callback=None,
+):
     """
     Request that updates a PodiumDevice
 
@@ -22,16 +28,16 @@ def make_device_update(token, device_uri, name=None,
         name(str): Name of the device.
 
         success_callback (function): Callback for a successful request,
-        will have the signature: 
+        will have the signature:
             on_success(result (dict), updated_uri (str))
         Defaults to None..
 
-        failure_callback (function): Callback for failures and errors. 
+        failure_callback (function): Callback for failures and errors.
         Will have the signature:
             on_failure(failure_type (string), result (dict), data (dict))
         Values for failure type are: 'error', 'failure'. Defaults to None.
 
-        redirect_callback (function): Callback for redirect, 
+        redirect_callback (function): Callback for redirect,
         Will have the signature:
             on_redirect(redirect_object (PodiumRedirect))
         Defaults to None.
@@ -47,28 +53,35 @@ def make_device_update(token, device_uri, name=None,
     """
     body = {}
     if name is not None:
-        body['device[name]'] = name
+        body["device[name]"] = name
     header = get_json_header_token(token)
     return make_request_custom_success(
-        device_uri, device_update_success_handler,
+        device_uri,
+        device_update_success_handler,
         method="PUT",
         success_callback=success_callback,
         redirect_callback=redirect_callback,
         failure_callback=failure_callback,
         progress_callback=progress_callback,
-        body=body, header=header,
-        data={'updated_uri': device_uri}
-        )
+        body=body,
+        header=header,
+        data={"updated_uri": device_uri},
+    )
 
 
-def make_devices_get(token, 
-                     start=None, per_page=None,
-                     expand=True,
-                     quiet=None, success_callback=None,
-                     redirect_callback=None,
-                     failure_callback=None, progress_callback=None):
+def make_devices_get(
+    token,
+    start=None,
+    per_page=None,
+    expand=True,
+    quiet=None,
+    success_callback=None,
+    redirect_callback=None,
+    failure_callback=None,
+    progress_callback=None,
+):
     """
-    Request that returns a PodiumPagedRequest of PodiumDevice. 
+    Request that returns a PodiumPagedRequest of PodiumDevice.
 
     Args:
         token (PodiumToken): The authentication token for this session.
@@ -86,12 +99,12 @@ def make_devices_get(token,
             on_success(PodiumPagedResponse)
         Defaults to None.
 
-        failure_callback (function): Callback for failures and errors. 
+        failure_callback (function): Callback for failures and errors.
         Will have the signature:
             on_failure(failure_type (string), result (dict), data (dict))
         Values for failure type are: 'error', 'failure'. Defaults to None.
 
-        redirect_callback (function): Callback for redirect, 
+        redirect_callback (function): Callback for redirect,
         Will have the signature:
             on_redirect(result (dict), data (dict))
         Defaults to None.
@@ -111,29 +124,33 @@ def make_devices_get(token,
     """
     params = {}
     if expand is not None:
-        params['expand'] = expand
+        params["expand"] = expand
     if quiet is not None:
-        params['quiet'] = quiet
+        params["quiet"] = quiet
     if start is not None:
-        params['start'] = start
+        params["start"] = start
     if per_page is not None:
         per_page = min(per_page, 100)
-        params['per_page'] = per_page
+        params["per_page"] = per_page
 
-    endpoint = '{}/api/v1/devices'.format(podium_api.PODIUM_APP.podium_url)
+    endpoint = "{}/api/v1/devices".format(podium_api.PODIUM_APP.podium_url)
     header = get_json_header_token(token)
-    return make_request_custom_success(endpoint, devices_success_handler,
-                                       method="GET",
-                                       success_callback=success_callback,
-                                       failure_callback=failure_callback,
-                                       progress_callback=progress_callback,
-                                       redirect_callback=redirect_callback,
-                                       params=params, header=header)
+    return make_request_custom_success(
+        endpoint,
+        devices_success_handler,
+        method="GET",
+        success_callback=success_callback,
+        failure_callback=failure_callback,
+        progress_callback=progress_callback,
+        redirect_callback=redirect_callback,
+        params=params,
+        header=header,
+    )
 
 
-def make_device_create(token, name,
-                       success_callback=None, failure_callback=None,
-                       progress_callback=None, redirect_callback=None):
+def make_device_create(
+    token, name, success_callback=None, failure_callback=None, progress_callback=None, redirect_callback=None
+):
     """
     Request that creates a new PodiumDevice.
 
@@ -147,16 +164,16 @@ def make_device_create(token, name,
 
     Kwargs:
         success_callback (function): Callback for a successful request,
-        will have the signature: 
+        will have the signature:
             on_success(result (dict), data (dict))
         Defaults to None..
 
-        failure_callback (function): Callback for failures and errors. 
+        failure_callback (function): Callback for failures and errors.
         Will have the signature:
             on_failure(failure_type (string), result (dict), data (dict))
         Values for failure type are: 'error', 'failure'. Defaults to None.
 
-        redirect_callback (function): Callback for redirect, 
+        redirect_callback (function): Callback for redirect,
         Will have the signature:
             on_redirect(redirect_object (PodiumRedirect))
         Defaults to None.
@@ -170,23 +187,26 @@ def make_device_create(token, name,
         UrlRequest: The request being made.
 
     """
-    endpoint = '{}/api/v1/devices'.format(podium_api.PODIUM_APP.podium_url)
-    body = {'device[name]': name}
+    endpoint = "{}/api/v1/devices".format(podium_api.PODIUM_APP.podium_url)
+    body = {"device[name]": name}
     header = get_json_header_token(token)
     return make_request_custom_success(
-        endpoint, None, method='POST',
+        endpoint,
+        None,
+        method="POST",
         success_callback=success_callback,
         redirect_callback=create_device_redirect_handler,
         failure_callback=failure_callback,
         progress_callback=progress_callback,
-        body=body, header=header,
-        data={'_redirect_callback': redirect_callback}
-        )
+        body=body,
+        header=header,
+        data={"_redirect_callback": redirect_callback},
+    )
 
 
-def make_device_delete(token, device_uri,
-                       success_callback=None, redirect_callback=None,
-                       failure_callback=None, progress_callback=None):
+def make_device_delete(
+    token, device_uri, success_callback=None, redirect_callback=None, failure_callback=None, progress_callback=None
+):
     """
     Deletes the device for the provided URI.
 
@@ -201,12 +221,12 @@ def make_device_delete(token, device_uri,
             on_success(deleted_uri (str))
         Defaults to None.
 
-        failure_callback (function): Callback for failures and errors. 
+        failure_callback (function): Callback for failures and errors.
         Will have the signature:
             on_failure(failure_type (string), result (dict), data (dict))
         Values for failure type are: 'error', 'failure'. Defaults to None.
 
-        redirect_callback (function): Callback for redirect, 
+        redirect_callback (function): Callback for redirect,
         Will have the signature:
             on_redirect(result (dict), data (dict))
         Defaults to None.
@@ -221,20 +241,29 @@ def make_device_delete(token, device_uri,
 
     """
     header = get_json_header_token(token)
-    return make_request_custom_success(device_uri, device_delete_handler,
-                                       method='DELETE',
-                                       success_callback=success_callback,
-                                       failure_callback=failure_callback,
-                                       progress_callback=progress_callback,
-                                       redirect_callback=redirect_callback,
-                                       header=header,
-                                       data={'deleted_uri': device_uri})
+    return make_request_custom_success(
+        device_uri,
+        device_delete_handler,
+        method="DELETE",
+        success_callback=success_callback,
+        failure_callback=failure_callback,
+        progress_callback=progress_callback,
+        redirect_callback=redirect_callback,
+        header=header,
+        data={"deleted_uri": device_uri},
+    )
 
 
-def make_device_get(token, device_uri, expand=True,
-                    quiet=None, success_callback=None,
-                    redirect_callback=None,
-                    failure_callback=None, progress_callback=None):
+def make_device_get(
+    token,
+    device_uri,
+    expand=True,
+    quiet=None,
+    success_callback=None,
+    redirect_callback=None,
+    failure_callback=None,
+    progress_callback=None,
+):
     """
     Request that returns a PodiumDevice for the provided device_uri
 
@@ -254,12 +283,12 @@ def make_device_get(token, device_uri, expand=True,
             on_success(PodiumEvent)
         Defaults to None.
 
-        failure_callback (function): Callback for failures and errors. 
+        failure_callback (function): Callback for failures and errors.
         Will have the signature:
             on_failure(failure_type (string), result (dict), data (dict))
         Values for failure type are: 'error', 'failure'. Defaults to None.
 
-        redirect_callback (function): Callback for redirect, 
+        redirect_callback (function): Callback for redirect,
         Will have the signature:
             on_redirect(result (dict), data (dict))
         Defaults to None.
@@ -275,17 +304,21 @@ def make_device_get(token, device_uri, expand=True,
     """
     params = {}
     if expand is not None:
-        params['expand'] = expand
+        params["expand"] = expand
     if quiet is not None:
-        params['quiet'] = quiet
+        params["quiet"] = quiet
     header = get_json_header_token(token)
-    return make_request_custom_success(device_uri, device_success_handler,
-                                       method='GET',
-                                       success_callback=success_callback,
-                                       failure_callback=failure_callback,
-                                       progress_callback=progress_callback,
-                                       redirect_callback=redirect_callback,
-                                       params=params, header=header)
+    return make_request_custom_success(
+        device_uri,
+        device_success_handler,
+        method="GET",
+        success_callback=success_callback,
+        failure_callback=failure_callback,
+        progress_callback=progress_callback,
+        redirect_callback=redirect_callback,
+        params=params,
+        header=header,
+    )
 
 
 def device_delete_handler(req, results, data):
@@ -300,14 +333,14 @@ def device_delete_handler(req, results, data):
         results (dict): Dict returned by the request.
 
         data (dict): Wildcard dict for containing data that needs to be passed
-        to the various callbacks of a request. Will contain at least a 
+        to the various callbacks of a request. Will contain at least a
         'success_callback' key.
 
     Return:
         None, this function instead calls a callback.
     """
-    if data['success_callback'] is not None:
-        data['success_callback'](data['deleted_uri'])
+    if data["success_callback"] is not None:
+        data["success_callback"](data["deleted_uri"])
 
 
 def devices_success_handler(req, results, data):
@@ -323,16 +356,15 @@ def devices_success_handler(req, results, data):
         results (dict): Dict returned by the request.
 
         data (dict): Wildcard dict for containing data that needs to be passed
-        to the various callbacks of a request. Will contain at least a 
+        to the various callbacks of a request. Will contain at least a
         'success_callback' key.
 
     Return:
         None, this function instead calls a callback.
 
     """
-    if data['success_callback'] is not None:
-        data['success_callback'](get_paged_response_from_json(results,
-                                                              'devices'))
+    if data["success_callback"] is not None:
+        data["success_callback"](get_paged_response_from_json(results, "devices"))
 
 
 def device_success_handler(req, results, data):
@@ -348,14 +380,14 @@ def device_success_handler(req, results, data):
         results (dict): Dict returned by the request.
 
         data (dict): Wildcard dict for containing data that needs to be passed
-        to the various callbacks of a request. Will contain at least a 
+        to the various callbacks of a request. Will contain at least a
         'success_callback' key.
 
     Return:
         None, this function instead calls a callback.
     """
-    if data['success_callback'] is not None:
-        data['success_callback'](get_device_from_json(results['device']))
+    if data["success_callback"] is not None:
+        data["success_callback"](get_device_from_json(results["device"]))
 
 
 def create_device_redirect_handler(req, results, data):
@@ -363,7 +395,7 @@ def create_device_redirect_handler(req, results, data):
     Handles the success redirect of a **make_device_create** call.
 
     Returns a PodiumRedirect with a uri for the newly created event to the
-    _redirect_callback found in data. 
+    _redirect_callback found in data.
 
     Automatically called by **make_device_create**, will call the
     redirect_callback passed in to **make_device_create** if there is on.
@@ -374,15 +406,15 @@ def create_device_redirect_handler(req, results, data):
         results (dict): Dict returned by the request.
 
         data (dict): Wildcard dict for containing data that needs to be passed
-        to the various callbacks of a request. Will contain at least a 
+        to the various callbacks of a request. Will contain at least a
         'success_callback' key.
 
     Return:
         None, this function instead calls a callback.
 
     """
-    if data['_redirect_callback'] is not None:
-        data['_redirect_callback'](get_redirect_from_json(results, 'device'))
+    if data["_redirect_callback"] is not None:
+        data["_redirect_callback"](get_redirect_from_json(results, "device"))
 
 
 def device_update_success_handler(req, results, data):
@@ -398,12 +430,12 @@ def device_update_success_handler(req, results, data):
         results (dict): Dict returned by the request.
 
         data (dict): Wildcard dict for containing data that needs to be passed
-        to the various callbacks of a request. Will contain at least a 
+        to the various callbacks of a request. Will contain at least a
         'success_callback' key.
 
     Return:
         None, this function instead calls a callback.
 
     """
-    if data['success_callback'] is not None:
-        data['success_callback'](results, data['updated_uri'])
+    if data["success_callback"] is not None:
+        data["success_callback"](results, data["updated_uri"])
