@@ -1,16 +1,25 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from podium_api.asyncreq import make_request_custom_success, get_json_header_token
-from podium_api.types.paged_response import get_paged_response_from_json
-from podium_api.types.event import get_event_from_json
-from podium_api.types.redirect import get_redirect_from_json
 import podium_api
+from podium_api.asyncreq import get_json_header_token, make_request_custom_success
+from podium_api.types.event import get_event_from_json
+from podium_api.types.paged_response import get_paged_response_from_json
+from podium_api.types.redirect import get_redirect_from_json
 
 
-def make_event_update(token, event_uri, title=None, start_time=None,
-                      end_time=None, venue_id=None, private=None,
-                      success_callback=None, failure_callback=None,
-                      progress_callback=None, redirect_callback=None):
+def make_event_update(
+    token,
+    event_uri,
+    title=None,
+    start_time=None,
+    end_time=None,
+    venue_id=None,
+    private=None,
+    success_callback=None,
+    failure_callback=None,
+    progress_callback=None,
+    redirect_callback=None,
+):
     """
     Request that updates a PodiumEvent.
 
@@ -27,20 +36,20 @@ def make_event_update(token, event_uri, title=None, start_time=None,
         start_time (str): Starting time, use ISO 8601 format.
 
         end_time (str): Ending time, use ISO 8601 format.
-        
+
         private (bool): True if it is a private event
 
         success_callback (function): Callback for a successful request,
-        will have the signature: 
+        will have the signature:
             on_success(result (dict), updated_uri (str))
         Defaults to None..
 
-        failure_callback (function): Callback for failures and errors. 
+        failure_callback (function): Callback for failures and errors.
         Will have the signature:
             on_failure(failure_type (string), result (dict), data (dict))
         Values for failure type are: 'error', 'failure'. Defaults to None.
 
-        redirect_callback (function): Callback for redirect, 
+        redirect_callback (function): Callback for redirect,
         Will have the signature:
             on_redirect(redirect_object (PodiumRedirect))
         Defaults to None.
@@ -56,32 +65,42 @@ def make_event_update(token, event_uri, title=None, start_time=None,
     """
     body = {}
     if title is not None:
-        body['event[title]'] = title
+        body["event[title]"] = title
     if start_time is not None:
-        body['event[start_time]'] = start_time
+        body["event[start_time]"] = start_time
     if end_time is not None:
-        body['event[end_time]'] = end_time
+        body["event[end_time]"] = end_time
     if venue_id is not None:
-        body['event[venue_id]'] = venue_id
+        body["event[venue_id]"] = venue_id
     if private is not None:
-        body['event[private]'] = str(private).lower()
+        body["event[private]"] = str(private).lower()
     header = get_json_header_token(token)
     return make_request_custom_success(
-        event_uri, event_update_success_handler,
+        event_uri,
+        event_update_success_handler,
         method="PUT",
         success_callback=success_callback,
         redirect_callback=redirect_callback,
         failure_callback=failure_callback,
         progress_callback=progress_callback,
-        body=body, header=header,
-        data={'updated_uri': event_uri}
-        )
+        body=body,
+        header=header,
+        data={"updated_uri": event_uri},
+    )
 
 
-def make_event_create(token, title, start_time, end_time, venue_id=None,
-                      private=None,
-                      success_callback=None, failure_callback=None,
-                      progress_callback=None, redirect_callback=None):
+def make_event_create(
+    token,
+    title,
+    start_time,
+    end_time,
+    venue_id=None,
+    private=None,
+    success_callback=None,
+    failure_callback=None,
+    progress_callback=None,
+    redirect_callback=None,
+):
     """
     Request that creates a new PodiumEvent.
 
@@ -96,23 +115,23 @@ def make_event_create(token, title, start_time, end_time, venue_id=None,
         start_time (str): Starting time, use ISO 8601 format.
 
         end_time (str): Ending time, use ISO 8601 format.
-        
+
         private (bool): True if it is a private event
 
     Kwargs:
         venue_id(str): ID for the venue of event.
 
         success_callback (function): Callback for a successful request,
-        will have the signature: 
+        will have the signature:
             on_success(result (dict), data (dict))
         Defaults to None..
 
-        failure_callback (function): Callback for failures and errors. 
+        failure_callback (function): Callback for failures and errors.
         Will have the signature:
             on_failure(failure_type (string), result (dict), data (dict))
         Values for failure type are: 'error', 'failure'. Defaults to None.
 
-        redirect_callback (function): Callback for redirect, 
+        redirect_callback (function): Callback for redirect,
         Will have the signature:
             on_redirect(redirect_object (PodiumRedirect))
         Defaults to None.
@@ -126,28 +145,30 @@ def make_event_create(token, title, start_time, end_time, venue_id=None,
         UrlRequest: The request being made.
 
     """
-    endpoint = '{}/api/v1/events'.format(podium_api.PODIUM_APP.podium_url)
-    body = {'event[title]': title, 'event[start_time]': start_time,
-            'event[end_time]': end_time}
+    endpoint = "{}/api/v1/events".format(podium_api.PODIUM_APP.podium_url)
+    body = {"event[title]": title, "event[start_time]": start_time, "event[end_time]": end_time}
     if venue_id is not None:
-        body['event[venue_id]'] = venue_id
+        body["event[venue_id]"] = venue_id
     if private is not None:
-        body['event[private]'] = str(private).lower()
+        body["event[private]"] = str(private).lower()
     header = get_json_header_token(token)
     return make_request_custom_success(
-        endpoint, None, method='POST',
+        endpoint,
+        None,
+        method="POST",
         success_callback=success_callback,
         redirect_callback=create_event_redirect_handler,
         failure_callback=failure_callback,
         progress_callback=progress_callback,
-        body=body, header=header,
-        data={'_redirect_callback': redirect_callback}
-        )
+        body=body,
+        header=header,
+        data={"_redirect_callback": redirect_callback},
+    )
 
 
-def make_event_delete(token, event_uri,
-                      success_callback=None, redirect_callback=None,
-                      failure_callback=None, progress_callback=None):
+def make_event_delete(
+    token, event_uri, success_callback=None, redirect_callback=None, failure_callback=None, progress_callback=None
+):
     """
     Deletes the event for the provided URI.
 
@@ -162,12 +183,12 @@ def make_event_delete(token, event_uri,
             on_success(deleted_uri (str))
         Defaults to None.
 
-        failure_callback (function): Callback for failures and errors. 
+        failure_callback (function): Callback for failures and errors.
         Will have the signature:
             on_failure(failure_type (string), result (dict), data (dict))
         Values for failure type are: 'error', 'failure'. Defaults to None.
 
-        redirect_callback (function): Callback for redirect, 
+        redirect_callback (function): Callback for redirect,
         Will have the signature:
             on_redirect(result (dict), data (dict))
         Defaults to None.
@@ -182,22 +203,31 @@ def make_event_delete(token, event_uri,
 
     """
     header = get_json_header_token(token)
-    return make_request_custom_success(event_uri, event_delete_handler,
-                                       method='DELETE',
-                                       success_callback=success_callback,
-                                       failure_callback=failure_callback,
-                                       progress_callback=progress_callback,
-                                       redirect_callback=redirect_callback,
-                                       header=header,
-                                       data={'deleted_uri': event_uri})
+    return make_request_custom_success(
+        event_uri,
+        event_delete_handler,
+        method="DELETE",
+        success_callback=success_callback,
+        failure_callback=failure_callback,
+        progress_callback=progress_callback,
+        redirect_callback=redirect_callback,
+        header=header,
+        data={"deleted_uri": event_uri},
+    )
 
 
-def make_event_get(token, event_uri, expand=True,
-                   quiet=None, success_callback=None,
-                   redirect_callback=None,
-                   failure_callback=None, progress_callback=None):
+def make_event_get(
+    token,
+    event_uri,
+    expand=True,
+    quiet=None,
+    success_callback=None,
+    redirect_callback=None,
+    failure_callback=None,
+    progress_callback=None,
+):
     """
-    Request that returns a PodiumEvent for the provided event_uri. 
+    Request that returns a PodiumEvent for the provided event_uri.
 
     Args:
         token (PodiumToken): The authentication token for this session.
@@ -215,12 +245,12 @@ def make_event_get(token, event_uri, expand=True,
             on_success(PodiumEvent)
         Defaults to None.
 
-        failure_callback (function): Callback for failures and errors. 
+        failure_callback (function): Callback for failures and errors.
         Will have the signature:
             on_failure(failure_type (string), result (dict), data (dict))
         Values for failure type are: 'error', 'failure'. Defaults to None.
 
-        redirect_callback (function): Callback for redirect, 
+        redirect_callback (function): Callback for redirect,
         Will have the signature:
             on_redirect(result (dict), data (dict))
         Defaults to None.
@@ -236,27 +266,38 @@ def make_event_get(token, event_uri, expand=True,
     """
     params = {}
     if expand is not None:
-        params['expand'] = expand
+        params["expand"] = expand
     if quiet is not None:
-        params['quiet'] = quiet
+        params["quiet"] = quiet
     header = get_json_header_token(token)
-    return make_request_custom_success(event_uri, event_success_handler,
-                                       method='GET',
-                                       success_callback=success_callback,
-                                       failure_callback=failure_callback,
-                                       progress_callback=progress_callback,
-                                       redirect_callback=redirect_callback,
-                                       params=params, header=header)
+    return make_request_custom_success(
+        event_uri,
+        event_success_handler,
+        method="GET",
+        success_callback=success_callback,
+        failure_callback=failure_callback,
+        progress_callback=progress_callback,
+        redirect_callback=redirect_callback,
+        params=params,
+        header=header,
+    )
 
 
-def make_events_get(token, start=None, per_page=None,
-                    endpoint=None, expand=True,
-                    quiet=None, success_callback=None,
-                    redirect_callback=None,
-                    failure_callback=None, progress_callback=None):
+def make_events_get(
+    token,
+    start=None,
+    per_page=None,
+    endpoint=None,
+    expand=True,
+    quiet=None,
+    success_callback=None,
+    redirect_callback=None,
+    failure_callback=None,
+    progress_callback=None,
+):
     """
-    Request that returns a PodiumPagedRequest of events. 
-    By default a get request to 
+    Request that returns a PodiumPagedRequest of events.
+    By default a get request to
     'https://podium.live/api/v1/events' will be made.
 
     Args:
@@ -273,12 +314,12 @@ def make_events_get(token, start=None, per_page=None,
             on_success(PodiumPagedResponse)
         Defaults to None.
 
-        failure_callback (function): Callback for failures and errors. 
+        failure_callback (function): Callback for failures and errors.
         Will have the signature:
             on_failure(failure_type (string), result (dict), data (dict))
         Values for failure type are: 'error', 'failure'. Defaults to None.
 
-        redirect_callback (function): Callback for redirect, 
+        redirect_callback (function): Callback for redirect,
         Will have the signature:
             on_redirect(result (dict), data (dict))
         Defaults to None.
@@ -300,26 +341,30 @@ def make_events_get(token, start=None, per_page=None,
 
     """
     if endpoint is None:
-        endpoint = '{}/api/v1/events'.format(podium_api.PODIUM_APP.podium_url)
+        endpoint = "{}/api/v1/events".format(podium_api.PODIUM_APP.podium_url)
     params = {}
     if expand is not None:
-        params['expand'] = expand
+        params["expand"] = expand
     if quiet is not None:
-        params['quiet'] = quiet
+        params["quiet"] = quiet
     if start is not None:
-        params['start'] = start
+        params["start"] = start
     if per_page is not None:
         per_page = min(per_page, 100)
-        params['per_page'] = per_page
+        params["per_page"] = per_page
 
     header = get_json_header_token(token)
-    return make_request_custom_success(endpoint, events_success_handler,
-                                       method='GET',
-                                       success_callback=success_callback,
-                                       failure_callback=failure_callback,
-                                       progress_callback=progress_callback,
-                                       redirect_callback=redirect_callback,
-                                       params=params, header=header)
+    return make_request_custom_success(
+        endpoint,
+        events_success_handler,
+        method="GET",
+        success_callback=success_callback,
+        failure_callback=failure_callback,
+        progress_callback=progress_callback,
+        redirect_callback=redirect_callback,
+        params=params,
+        header=header,
+    )
 
 
 def event_delete_handler(req, results, data):
@@ -334,14 +379,14 @@ def event_delete_handler(req, results, data):
         results (dict): Dict returned by the request.
 
         data (dict): Wildcard dict for containing data that needs to be passed
-        to the various callbacks of a request. Will contain at least a 
+        to the various callbacks of a request. Will contain at least a
         'success_callback' key.
 
     Return:
         None, this function instead calls a callback.
     """
-    if data['success_callback'] is not None:
-        data['success_callback'](data['deleted_uri'])
+    if data["success_callback"] is not None:
+        data["success_callback"](data["deleted_uri"])
 
 
 def event_success_handler(req, results, data):
@@ -357,14 +402,14 @@ def event_success_handler(req, results, data):
         results (dict): Dict returned by the request.
 
         data (dict): Wildcard dict for containing data that needs to be passed
-        to the various callbacks of a request. Will contain at least a 
+        to the various callbacks of a request. Will contain at least a
         'success_callback' key.
 
     Return:
         None, this function instead calls a callback.
     """
-    if data['success_callback'] is not None:
-        data['success_callback'](get_event_from_json(results['event']))
+    if data["success_callback"] is not None:
+        data["success_callback"](get_event_from_json(results["event"]))
 
 
 def events_success_handler(req, results, data):
@@ -380,16 +425,15 @@ def events_success_handler(req, results, data):
         results (dict): Dict returned by the request.
 
         data (dict): Wildcard dict for containing data that needs to be passed
-        to the various callbacks of a request. Will contain at least a 
+        to the various callbacks of a request. Will contain at least a
         'success_callback' key.
 
     Return:
         None, this function instead calls a callback.
 
     """
-    if data['success_callback'] is not None:
-        data['success_callback'](get_paged_response_from_json(results,
-                                                              'events'))
+    if data["success_callback"] is not None:
+        data["success_callback"](get_paged_response_from_json(results, "events"))
 
 
 def create_event_redirect_handler(req, results, data):
@@ -397,7 +441,7 @@ def create_event_redirect_handler(req, results, data):
     Handles the success redirect of a **make_event_create** call.
 
     Returns a PodiumRedirect with a uri for the newly created event to the
-    _redirect_callback found in data. 
+    _redirect_callback found in data.
 
     Automatically called by **make_event_create**, will call the
     redirect_callback passed in to **make_event_create** if there is on.
@@ -408,15 +452,15 @@ def create_event_redirect_handler(req, results, data):
         results (dict): Dict returned by the request.
 
         data (dict): Wildcard dict for containing data that needs to be passed
-        to the various callbacks of a request. Will contain at least a 
+        to the various callbacks of a request. Will contain at least a
         'success_callback' key.
 
     Return:
         None, this function instead calls a callback.
 
     """
-    if data['_redirect_callback'] is not None:
-        data['_redirect_callback'](get_redirect_from_json(results, 'event'))
+    if data["_redirect_callback"] is not None:
+        data["_redirect_callback"](get_redirect_from_json(results, "event"))
 
 
 def event_update_success_handler(req, results, data):
@@ -432,12 +476,12 @@ def event_update_success_handler(req, results, data):
         results (dict): Dict returned by the request.
 
         data (dict): Wildcard dict for containing data that needs to be passed
-        to the various callbacks of a request. Will contain at least a 
+        to the various callbacks of a request. Will contain at least a
         'success_callback' key.
 
     Return:
         None, this function instead calls a callback.
 
     """
-    if data['success_callback'] is not None:
-        data['success_callback'](results, data['updated_uri'])
+    if data["success_callback"] is not None:
+        data["success_callback"](results, data["updated_uri"])
