@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
+from typing import Any
+import json
 
 class PodiumAccount(object):
     """
@@ -32,12 +33,19 @@ class PodiumAccount(object):
         self.email = email
         self.account_type = account_type
         self.features = features
+        try:
+            self._features_dict = json.loads(features)
+        except:
+            self._features_dict = {}
         self.devices_uri = devices_uri
         self.exports_uri = exports_uri
         self.streams_uri = streams_uri
         self.user_uri = user_uri
         self.events_uri = events_uri
 
+    def has_feature(self, feature_key: str, expected_value: Any) -> str:
+        feature = self._features_dict.get(feature_key)
+        return feature and feature == expected_value 
 
 def get_account_from_json(json):
     """
